ClassAnnotatedWithTypeNameEndingShouldRules extension

Condition-side DSL for class annotation suffix rules.

on

Methods

beAnnotatedWithTypeNameEnding(String suffix) HeimdallRule<CompilationUnitMember>

Available on ClassShouldBuilder, provided by the ClassAnnotatedWithTypeNameEndingShouldRules extension

Requires matching classes to be annotated with a type name ending with suffix.
beAnnotatedWithTypeNameEndingAll(Iterable<String> suffixes) HeimdallRule<CompilationUnitMember>

Available on ClassShouldBuilder, provided by the ClassAnnotatedWithTypeNameEndingShouldRules extension

Requires matching classes to be annotated with type names ending with every suffix in suffixes.
beAnnotatedWithTypeNameEndingAny(Iterable<String> suffixes) HeimdallRule<CompilationUnitMember>

Available on ClassShouldBuilder, provided by the ClassAnnotatedWithTypeNameEndingShouldRules extension

Requires matching classes to be annotated with a type name ending with any suffix in suffixes.
beAnnotatedWithTypeNameEndingNone(Iterable<String> suffixes) HeimdallRule<CompilationUnitMember>

Available on ClassShouldBuilder, provided by the ClassAnnotatedWithTypeNameEndingShouldRules extension

Requires matching classes to be annotated with no name ending with suffixes.
noBeAnnotatedWithTypeNameEnding(String suffix) HeimdallRule<CompilationUnitMember>

Available on ClassShouldBuilder, provided by the ClassAnnotatedWithTypeNameEndingShouldRules extension

Requires matching classes to not be annotated with a type name ending with suffix.