ClassDeclareFactoryConstructorShouldRules extension
Condition-side DSL for factory constructor rules.
Methods
-
declareAllFactoryConstructors(
Iterable< String> names) → HeimdallRule<CompilationUnitMember> -
Available on ClassShouldBuilder, provided by the ClassDeclareFactoryConstructorShouldRules extension
Requires matching classes to declare everyfactoryconstructor innames. -
declareAnyFactoryConstructor(
Iterable< String> names) → HeimdallRule<CompilationUnitMember> -
Available on ClassShouldBuilder, provided by the ClassDeclareFactoryConstructorShouldRules extension
Requires matching classes to declare at least onefactoryconstructor innames. -
declareFactoryConstructor(
{String name = 'new'}) → HeimdallRule< CompilationUnitMember> -
Available on ClassShouldBuilder, provided by the ClassDeclareFactoryConstructorShouldRules extension
Requires matching classes to declare afactoryconstructor. -
declareNoFactoryConstructors(
Iterable< String> names) → HeimdallRule<CompilationUnitMember> -
Available on ClassShouldBuilder, provided by the ClassDeclareFactoryConstructorShouldRules extension
Requires matching classes to declare none of thefactoryconstructors innames. -
noDeclareFactoryConstructor(
{String name = 'new'}) → HeimdallRule< CompilationUnitMember> -
Available on ClassShouldBuilder, provided by the ClassDeclareFactoryConstructorShouldRules extension
Requires matching classes to not declare afactoryconstructor namedname.