ClassFieldCountShouldRules extension

Condition-side DSL for class field-count rules.

on

Methods

haveAtMostFields(int count) → HeimdallRule<CompilationUnitMember>

Available on ClassShouldBuilder, provided by the ClassFieldCountShouldRules extension

Requires classes to declare count or fewer instance fields.
haveFieldCount(int count) → HeimdallRule<CompilationUnitMember>

Available on ClassShouldBuilder, provided by the ClassFieldCountShouldRules extension

Requires classes to declare exactly count instance fields.
haveFieldCountOtherThan(int count) → HeimdallRule<CompilationUnitMember>

Available on ClassShouldBuilder, provided by the ClassFieldCountShouldRules extension

Requires classes not to declare exactly count instance fields.
haveMoreThanFields(int count) → HeimdallRule<CompilationUnitMember>

Available on ClassShouldBuilder, provided by the ClassFieldCountShouldRules extension

Requires classes to declare more than count instance fields.