ClassHaveConstructorNameStartingWithShouldRules extension

Condition-side DSL for constructor name prefix rules.

on

Methods

declareConstructorWithNameStartingWith(String prefix) → HeimdallRule<CompilationUnitMember>

Available on ClassShouldBuilder, provided by the ClassHaveConstructorNameStartingWithShouldRules extension

Requires matching classes to declare a constructor name starting with prefix.
declareConstructorWithNameStartingWithAllOf(Iterable<String> prefixes) → HeimdallRule<CompilationUnitMember>

Available on ClassShouldBuilder, provided by the ClassHaveConstructorNameStartingWithShouldRules extension

Requires matching classes to declare constructor names starting with every prefix in prefixes.
declareConstructorWithNameStartingWithAnyOf(Iterable<String> prefixes) → HeimdallRule<CompilationUnitMember>

Available on ClassShouldBuilder, provided by the ClassHaveConstructorNameStartingWithShouldRules extension

Requires matching classes to declare at least one constructor name starting with prefixes.
declareConstructorWithNameStartingWithNoneOf(Iterable<String> prefixes) → HeimdallRule<CompilationUnitMember>

Available on ClassShouldBuilder, provided by the ClassHaveConstructorNameStartingWithShouldRules extension

Requires matching classes to declare no constructor name starting with prefixes.
notDeclareConstructorWithNameStartingWith(String prefix) → HeimdallRule<CompilationUnitMember>

Available on ClassShouldBuilder, provided by the ClassHaveConstructorNameStartingWithShouldRules extension

Requires matching classes to not declare a constructor name starting with prefix.