Directive class sealed
A node that represents a directive.
directive ::= ExportDirective | ImportDirective | LibraryDirective | PartDirective | PartOfDirective
- Implemented types
- Available extensions
- Annotations
-
- @AnalyzerPublicApi.new(message: 'exported by lib/dart/ast/ast.dart')
Properties
- beginToken → Token
-
The first token included in this node's source range.
no setterinherited
-
childEntities
→ Iterable<
SyntacticEntity> -
An iterator that can be used to iterate through all the entities (either
AST nodes or tokens) that make up the contents of this node, including doc
comments but excluding other comments.
no setterinherited
- documentationComment → Comment?
-
The documentation comment associated with this node, or
nullif this node doesn't have a documentation comment associated with it.no setterinherited - end → int
-
The offset of the character immediately following the last character of
this node's source range.
no setterinherited
- endToken → Token
-
The last token included in this node's source range.
no setterinherited
- firstTokenAfterCommentAndMetadata → Token
-
The first token following the comment and metadata.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSynthetic → bool
-
Whether this node is a synthetic node.
no setterinherited
- length → int
-
Return the number of characters in the syntactic entity's source range.
no setterinherited
- line → int
-
Available on Directive, provided by the HeimdallDependency extension
One-based source line of the directive.no setter -
metadata
→ NodeList<
Annotation> -
The annotations associated with this node.
no setterinherited
- offset → int
-
Return the offset from the beginning of the file to the first character in
the syntactic entity.
no setterinherited
- originPath → String
-
Available on Directive, provided by the HeimdallDependency extension
Absolute path of the file where this directive was declared.no setter - parent → AstNode?
-
Returns this node's parent node, or
nullif this node is the root of an AST structure.no setterinherited - root → AstNode
-
The node at the root of this node's AST structure.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sortedCommentAndAnnotations
→ List<
AstNode> -
A list containing the comment and annotations associated with this node,
sorted in lexical order.
no setterinherited
- sourceRange → SourceRange
-
Returns a
SourceRangeobject describing the range of characters spanned by this syntactic entity.no setterinherited - targetFile → HeimdallSourceFile?
-
Available on Directive, provided by the HeimdallDependency extension
Resolved imported, exported, or parted file, when it is in scope.no setter - targetPath → String?
-
Available on Directive, provided by the HeimdallDependency extension
Absolute path resolved from the target URI, when local to the project.no setter - targetUri → String?
-
Available on Directive, provided by the HeimdallDependency extension
Textual URI of the directive.no setter
Methods
-
accept<
E> (AstVisitor< E> visitor) → E? -
Use the given
visitorto visit this node.inherited -
findPrevious(
Token target) → Token? -
Returns the token before
target, ornullif it can't be found.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
thisOrAncestorMatching<
E extends AstNode> (bool predicate(AstNode)) → E? -
Returns either this node or the most immediate ancestor of this node for
which the
predicatereturnstrue, ornullif there's no such node.inherited -
thisOrAncestorOfType<
E extends AstNode> () → E? -
Returns either this node or the most immediate ancestor of this node that
has the given type, or
nullif there's no such node.inherited -
toSource(
) → String -
Returns a textual description of this node in a form approximating valid
source.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
visitChildren(
AstVisitor visitor) → void -
Use the given
visitorto visit all of the children of this node.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited