The declaration of an enumeration.
enumType ::= metadata 'enum' name TypeParameterList? WithClause? ImplementsClause? '{' SimpleIdentifier (',' SimpleIdentifier)* (';' ClassMember+)? '}'
- Implemented types
- Available extensions
- Annotations
-
- @AnalyzerPublicApi.new(message: 'exported by lib/dart/ast/ast.dart')
Properties
-
annotations
→ List<
String> -
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
Nomes das anotações declaradas no nó.no setter - augmentKeyword → Token?
-
The
augmentkeyword, ornullif the keyword was absent.no setter - beginToken → Token
-
The first token included in this node's source range.
no setterinherited
- body → EnumBody
-
The body of the enum declaration.
no setter
-
childEntities
→ Iterable<
SyntacticEntity> -
An iterator that can be used to iterate through all the entities (either
AST nodes or tokens) that make up the contents of this node, including doc
comments but excluding other comments.
no setterinherited
- declaredFragment → EnumFragment?
-
The fragment declared by this declaration.
no setteroverride
- documentationComment → Comment?
-
The documentation comment associated with this node, or
nullif this node doesn't have a documentation comment associated with it.no setterinherited - end → int
-
The offset of the character immediately following the last character of
this node's source range.
no setterinherited
- endToken → Token
-
The last token included in this node's source range.
no setterinherited
- enumKeyword → Token
-
The
enumkeyword.no setter - firstTokenAfterCommentAndMetadata → Token
-
The first token following the comment and metadata.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- implementsClause → ImplementsClause?
-
The
implementsclause for the enumeration, ornullif the enumeration doesn't implement any interfaces.no setter - isAbstract → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truepara classes com modificadorabstract.no setter - isBase → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truepara classes ou mixins com modificadorbase.no setter - isEnum → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truepara EnumDeclaration.no setter - isExtension → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truepara ExtensionDeclaration.no setter - isExtensionType → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truepara ExtensionTypeDeclaration.no setter - isFinal → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truepara classes com modificadorfinal.no setter - isInterface → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truepara classes com modificadorinterface.no setter - isMixin → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truepara MixinDeclaration.no setter - isPrivate → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truequando o nome começa com_.no setter - isPublic → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truequando o nome não começa com_.no setter - isSealed → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truepara classes com modificadorsealed.no setter - isSynthetic → bool
-
Whether this node is a synthetic node.
no setterinherited
- isTypeDeclaration → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truepara declarações que a DSL declasses()deve tratar como tipos.no setter - length → int
-
Return the number of characters in the syntactic entity's source range.
no setterinherited
- line → int
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
Linha inicial da declaração no arquivo.no setter -
members
→ List<
ClassMember> -
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
Membros declarados no corpo da declaração, quando ela possui corpo.no setter -
metadata
→ NodeList<
Annotation> -
The annotations associated with this node.
no setterinherited
- name → String
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
Nome humano da declaração.no setter - namePart → ClassNamePart
-
The name of the enum, as an identifier with type parameters,
or a primary constructor.
no setter
- offset → int
-
Return the offset from the beginning of the file to the first character in
the syntactic entity.
no setterinherited
- parent → AstNode?
-
Returns this node's parent node, or
nullif this node is the root of an AST structure.no setterinherited - relativePath → String
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
Caminho relativo à raiz importada.no setter - root → AstNode
-
The node at the root of this node's AST structure.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sortedCommentAndAnnotations
→ List<
AstNode> -
A list containing the comment and annotations associated with this node,
sorted in lexical order.
no setterinherited
- sourcePath → String
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
Caminho absoluto do arquivo de origem.no setter - sourceRange → SourceRange
-
Returns a
SourceRangeobject describing the range of characters spanned by this syntactic entity.no setterinherited - withClause → WithClause?
-
The
withclause for the enumeration, ornullif the enumeration doesn't have awithclause.no setter
Methods
-
accept<
E> (AstVisitor< E> visitor) → E? -
Use the given
visitorto visit this node.inherited -
findPrevious(
Token target) → Token? -
Returns the token before
target, ornullif it can't be found.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sourceLocationAt(
int sourceOffset) → ({int column, int line}) -
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
Source location forsourceOffsetinside the declaration file. -
thisOrAncestorMatching<
E extends AstNode> (bool predicate(AstNode)) → E? -
Returns either this node or the most immediate ancestor of this node for
which the
predicatereturnstrue, ornullif there's no such node.inherited -
thisOrAncestorOfType<
E extends AstNode> () → E? -
Returns either this node or the most immediate ancestor of this node that
has the given type, or
nullif there's no such node.inherited -
toSource(
) → String -
Returns a textual description of this node in a form approximating valid
source.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
visitChildren(
AstVisitor visitor) → void -
Use the given
visitorto visit all of the children of this node.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited