ExcludeGeneratedDartImportOption class final

Excludes common generated Dart files.

Files ending in .g.dart, .freezed.dart, or .gr.dart are skipped.

Implemented types

Constructors

ExcludeGeneratedDartImportOption()
Creates an option that excludes generated Dart files.
const

Properties

cacheKey String
Stable key used by the importer cache.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

includes(String absolutePath) bool
Returns true when absolutePath should be imported.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited