A function declaration.
Wrapped in a FunctionDeclarationStatement to represent a local function declaration, otherwise a top-level function declaration.
functionDeclaration ::= 'external' functionSignature | functionSignature FunctionBody
functionSignature ::= Type? ('get' | 'set')? name FormalParameterList
- Implemented types
- Available extensions
- Annotations
-
- @AnalyzerPublicApi.new(message: 'exported by lib/dart/ast/ast.dart')
Properties
-
annotationNodes
→ List<
Annotation> -
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
Annotation nodes declared on this node.no setter -
annotations
→ List<
String> -
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
Annotation type names declared on this node.no setter - augmentKeyword → Token?
-
The
augmentkeyword, ornullif there is noaugmentkeyword.no setter - beginToken → Token
-
The first token included in this node's source range.
no setterinherited
-
childEntities
→ Iterable<
SyntacticEntity> -
An iterator that can be used to iterate through all the entities (either
AST nodes or tokens) that make up the contents of this node, including doc
comments but excluding other comments.
no setterinherited
-
constructors
→ List<
ConstructorDeclaration> -
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
Constructor declarations owned by this declaration.no setter - declaredFragment → ExecutableFragment?
-
The fragment declared by this declaration.
no setteroverride
- documentationComment → Comment?
-
The documentation comment associated with this node, or
nullif this node doesn't have a documentation comment associated with it.no setterinherited - end → int
-
The offset of the character immediately following the last character of
this node's source range.
no setterinherited
- endToken → Token
-
The last token included in this node's source range.
no setterinherited
- externalKeyword → Token?
-
The token representing the
externalkeyword, ornullif this isn't an external function.no setter -
fields
→ List<
FieldDeclaration> -
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
Field declarations owned by this declaration.no setter -
fieldVariables
→ List<
VariableDeclaration> -
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
Individual field variables owned by this declaration.no setter - firstTokenAfterCommentAndMetadata → Token
-
The first token following the comment and metadata.
no setterinherited
- functionExpression → FunctionExpression
-
The function expression being wrapped.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAbstract → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truefor classes with theabstractmodifier.no setter - isBase → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truefor classes or mixins with thebasemodifier.no setter - isEnum → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truepara EnumDeclaration.no setter - isExtension → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truepara ExtensionDeclaration.no setter - isExtensionType → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truepara ExtensionTypeDeclaration.no setter - isFinal → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truefor classes with thefinalmodifier.no setter - isGetter → bool
-
Whether this function declares a getter.
no setter
- isInterface → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truefor classes with theinterfacemodifier.no setter - isMixin → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truepara MixinDeclaration.no setter - isPrivate → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truewhen the name starts with_.no setter - isPublic → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truewhen the name does not start with_.no setter - isSealed → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truefor classes with thesealedmodifier.no setter - isSetter → bool
-
Whether this function declares a setter.
no setter
- isSynthetic → bool
-
Whether this node is a synthetic node.
no setterinherited
- isTypeDeclaration → bool
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
truefor declarations thatHeimdall.classes()treats as types.no setter - length → int
-
Return the number of characters in the syntactic entity's source range.
no setterinherited
- line → int
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
One-based line where the declaration starts.no setter - location → CharacterLocation
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
Analyzer source location where the declaration starts.no setter -
members
→ List<
ClassMember> -
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
Members declared in the declaration body, when it has one.no setter -
metadata
→ NodeList<
Annotation> -
The annotations associated with this node.
no setterinherited
-
methods
→ List<
MethodDeclaration> -
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
Method declarations owned by this declaration.no setter - name → String
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
Human-readable declaration name.no setter - name → Token
-
The name of the function.
no setter
- offset → int
-
Return the offset from the beginning of the file to the first character in
the syntactic entity.
no setterinherited
- parent → AstNode?
-
Returns this node's parent node, or
nullif this node is the root of an AST structure.no setterinherited - propertyKeyword → Token?
-
The token representing the
getorsetkeyword, ornullif this is a function declaration rather than a property declaration.no setter - relativePath → String
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
Path relative to the imported root.no setter - returnType → TypeAnnotation?
-
The return type of the function, or
nullif no return type was declared.no setter - root → AstNode
-
The node at the root of this node's AST structure.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sortedCommentAndAnnotations
→ List<
AstNode> -
A list containing the comment and annotations associated with this node,
sorted in lexical order.
no setterinherited
- sourcePath → String
-
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
Absolute path of the source file.no setter - sourceRange → SourceRange
-
Returns a
SourceRangeobject describing the range of characters spanned by this syntactic entity.no setterinherited
Methods
-
accept<
E> (AstVisitor< E> visitor) → E? -
Use the given
visitorto visit this node.inherited -
findPrevious(
Token target) → Token? -
Returns the token before
target, ornullif it can't be found.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sourceLocationAt(
int sourceOffset) → ({int column, int line}) -
Available on CompilationUnitMember, provided by the HeimdallDeclaration extension
Source location forsourceOffsetinside the declaration file. -
thisOrAncestorMatching<
E extends AstNode> (bool predicate(AstNode)) → E? -
Returns either this node or the most immediate ancestor of this node for
which the
predicatereturnstrue, ornullif there's no such node.inherited -
thisOrAncestorOfType<
E extends AstNode> () → E? -
Returns either this node or the most immediate ancestor of this node that
has the given type, or
nullif there's no such node.inherited -
toSource(
) → String -
Returns a textual description of this node in a form approximating valid
source.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
visitChildren(
AstVisitor visitor) → void -
Use the given
visitorto visit all of the children of this node.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited