ClassAnnotatedWithTypeNameEndingShouldRules extension
Condition-side DSL for class annotation suffix rules.
Methods
-
beAnnotatedWithTypeNameEnding(
String suffix) → HeimdallRule< CompilationUnitMember> -
Available on ClassShouldBuilder, provided by the ClassAnnotatedWithTypeNameEndingShouldRules extension
Requires matching classes to be annotated with a type name ending withsuffix. -
beAnnotatedWithTypeNameEndingAll(
Iterable< String> suffixes) → HeimdallRule<CompilationUnitMember> -
Available on ClassShouldBuilder, provided by the ClassAnnotatedWithTypeNameEndingShouldRules extension
Requires matching classes to be annotated with type names ending with every suffix insuffixes. -
beAnnotatedWithTypeNameEndingAny(
Iterable< String> suffixes) → HeimdallRule<CompilationUnitMember> -
Available on ClassShouldBuilder, provided by the ClassAnnotatedWithTypeNameEndingShouldRules extension
Requires matching classes to be annotated with a type name ending with any suffix insuffixes. -
beAnnotatedWithTypeNameEndingNone(
Iterable< String> suffixes) → HeimdallRule<CompilationUnitMember> -
Available on ClassShouldBuilder, provided by the ClassAnnotatedWithTypeNameEndingShouldRules extension
Requires matching classes to be annotated with no name ending withsuffixes. -
noBeAnnotatedWithTypeNameEnding(
String suffix) → HeimdallRule< CompilationUnitMember> -
Available on ClassShouldBuilder, provided by the ClassAnnotatedWithTypeNameEndingShouldRules extension
Requires matching classes to not be annotated with a type name ending withsuffix.