beAssignableToTypeNameEndingWithAll method
Requires matching classes to be assignable to type names ending with every suffix in suffixes.
Implementation
HeimdallRule<CompilationUnitMember> beAssignableToTypeNameEndingWithAll(
Iterable<String> suffixes,
) {
final suffixList = suffixes.toNonEmptyList('suffixes');
return satisfy(
HeimdallCondition.allOf(
suffixList.map(_classShouldBeAssignableToTypeNameEndingWith),
description: 'be assignable to type names ending with all of ${suffixList.join(', ')}',
),
);
}