ClassHaveConstructorNameStartingWithShouldRules extension
Condition-side DSL for constructor name prefix rules.
Methods
-
declareConstructorWithNameStartingWith(
String prefix) → HeimdallRule< CompilationUnitMember> -
Available on ClassShouldBuilder, provided by the ClassHaveConstructorNameStartingWithShouldRules extension
Requires matching classes to declare a constructor name starting withprefix. -
declareConstructorWithNameStartingWithAllOf(
Iterable< String> prefixes) → HeimdallRule<CompilationUnitMember> -
Available on ClassShouldBuilder, provided by the ClassHaveConstructorNameStartingWithShouldRules extension
Requires matching classes to declare constructor names starting with every prefix inprefixes. -
declareConstructorWithNameStartingWithAnyOf(
Iterable< String> prefixes) → HeimdallRule<CompilationUnitMember> -
Available on ClassShouldBuilder, provided by the ClassHaveConstructorNameStartingWithShouldRules extension
Requires matching classes to declare at least one constructor name starting withprefixes. -
declareConstructorWithNameStartingWithNoneOf(
Iterable< String> prefixes) → HeimdallRule<CompilationUnitMember> -
Available on ClassShouldBuilder, provided by the ClassHaveConstructorNameStartingWithShouldRules extension
Requires matching classes to declare no constructor name starting withprefixes. -
notDeclareConstructorWithNameStartingWith(
String prefix) → HeimdallRule< CompilationUnitMember> -
Available on ClassShouldBuilder, provided by the ClassHaveConstructorNameStartingWithShouldRules extension
Requires matching classes to not declare a constructor name starting withprefix.