ClassHaveConstructorNameStartingWithShouldRules extension

Condition-side DSL for constructor name prefix rules.

on

Methods

haveConstructorNameStartingWith(String prefix) HeimdallRule<CompilationUnitMember>

Available on ClassShouldBuilder, provided by the ClassHaveConstructorNameStartingWithShouldRules extension

Requires matching classes to declare a constructor name starting with prefix.
haveConstructorNameStartingWithAll(Iterable<String> prefixes) HeimdallRule<CompilationUnitMember>

Available on ClassShouldBuilder, provided by the ClassHaveConstructorNameStartingWithShouldRules extension

Requires matching classes to declare constructor names starting with every prefix in prefixes.
haveConstructorNameStartingWithAny(Iterable<String> prefixes) HeimdallRule<CompilationUnitMember>

Available on ClassShouldBuilder, provided by the ClassHaveConstructorNameStartingWithShouldRules extension

Requires matching classes to declare at least one constructor name starting with prefixes.
haveConstructorNameStartingWithNone(Iterable<String> prefixes) HeimdallRule<CompilationUnitMember>

Available on ClassShouldBuilder, provided by the ClassHaveConstructorNameStartingWithShouldRules extension

Requires matching classes to declare no constructor name starting with prefixes.
noHaveConstructorNameStartingWith(String prefix) HeimdallRule<CompilationUnitMember>

Available on ClassShouldBuilder, provided by the ClassHaveConstructorNameStartingWithShouldRules extension

Requires matching classes to not declare a constructor name starting with prefix.