ClassHaveConstructorNameStartingWithShouldRules extension
Condition-side DSL for constructor name prefix rules.
Methods
-
haveConstructorNameStartingWith(
String prefix) → HeimdallRule< CompilationUnitMember> -
Available on ClassShouldBuilder, provided by the ClassHaveConstructorNameStartingWithShouldRules extension
Requires matching classes to declare a constructor name starting withprefix. -
haveConstructorNameStartingWithAll(
Iterable< String> prefixes) → HeimdallRule<CompilationUnitMember> -
Available on ClassShouldBuilder, provided by the ClassHaveConstructorNameStartingWithShouldRules extension
Requires matching classes to declare constructor names starting with every prefix inprefixes. -
haveConstructorNameStartingWithAny(
Iterable< String> prefixes) → HeimdallRule<CompilationUnitMember> -
Available on ClassShouldBuilder, provided by the ClassHaveConstructorNameStartingWithShouldRules extension
Requires matching classes to declare at least one constructor name starting withprefixes. -
haveConstructorNameStartingWithNone(
Iterable< String> prefixes) → HeimdallRule<CompilationUnitMember> -
Available on ClassShouldBuilder, provided by the ClassHaveConstructorNameStartingWithShouldRules extension
Requires matching classes to declare no constructor name starting withprefixes. -
noHaveConstructorNameStartingWith(
String prefix) → HeimdallRule< CompilationUnitMember> -
Available on ClassShouldBuilder, provided by the ClassHaveConstructorNameStartingWithShouldRules extension
Requires matching classes to not declare a constructor name starting withprefix.